
//This is called on startup, and each time the world loads
void doSettings()
{
	//Change this to true if you want to start in fullscreen mode
	setFullscreen(false);

	//Change these (width, height) to alter the starting window size or fullscreen dimensions
	//For fullscreen, if the dimensions are unsupported the current desktop dimensions will be used, I think
	setDisplayDimensions(640, 480);
	
	////////////
	//Settings below here will be reloaded at runtime when a new game starts
	
	//Change this to show Box2D's debug draw data
	setDoDebugDraw(false);
	
	//Change this to alter the camera style
	//0 = follow player, 1 = pan with right mouse button + mouse wheel to zoom
	setCameraMode(0);
	
	//Change these to affect the player movement
	//(runStrength, runSpeed, jumpStrength, airSteerStrength)
	setPlayerStats(7.5, 12.5, 3.75, 2.75);
}


//This is called when a named actor fixture touches an event sensor
//Actor fixtures are those named "playerUpper" (actorId = 0), or "carLower" (actorId = 1)
//Event sensors are those named "event%d" in the json, eg. event0, event1
//Return true for a once-only event (this will destroy the named fixture)
bool runEvent(int actorId, int eventSensorId)
{
	switch (actorId)
	{
		case -1://scheduled by script
			runScheduledEvent(eventSensorId);
			break;
		case 0: //player
			return runPlayerEvent(eventSensorId);
		case 1: //buddy
			return runBuddyEvent(eventSensorId);
		case 2: //car
			return runCarEvent(eventSensorId);
	}
	
	//default is to keep sensors
	return false;
}

bool okToReleaseKittens = false;

//return true to destroy the event sensor
bool runPlayerEvent(int eventSensorId)
{
	switch (eventSensorId)
	{
		case 0: narrate(-1, 0, "There's some kind of invisible wall there... :)", 2); return false;
		case 4: destroyJoint("weaklink1");
			scheduleEvent(5, 1.5);
			scheduleEvent(7, 0.3);
			return true;
		case 7: scheduleEvent(8, 2); return true;
		case 12: narrate(0, 1, "Yup, I'm definitely alone, no doubt about that.", 6); return true;
		case 13: narrate(0, 1, "Hmm... guess I'd better try the other way.", 6); return true;
		case 16: narrate(0, 1, "Hold on, I just need to jump on the car.", 6);
			narrate(1, 1, "Hey! Get off of that!", 6);
			scheduleEvent(17,2.5);
			return true;
		case 31: narrate(0, 1, "So, how much further?", 4); scheduleEvent(32,1.5); return true;
		case 34: destroyFixture("trapdoor1");
			narrate(-1, 0, "The earth shudders...", 6);
			narrate(0, 1, "?!?!!", 3);
			scheduleEvent(35,3);
			return true;
		case 39: narrate(0, 1, "That slope looks slippery...", 4); return true;
		case 40: narrate(0, 1, "Wow! I is ever so clever.", 4); return true;
		case 41: narrate(0, 1, "Yup. I am smert.", 4); return true;
		case 42: narrate(0, 1, "Yes!! I can see daylight through here!", 4); return true;
		case 43: destroyFixture("trapdoor2");
			narrate(-1, 0, "The earth shudders again...", 6);
			narrate(0, 1, "What?!?!!", 3);
			okToReleaseKittens = true;
			scheduleEvent(44,3);
			return true;
		case 48: if ( okToReleaseKittens ) {
				destroyFixture("kittenTrapdoor");
				scheduleEvent(49,2);
				return true;
			}
			else return false;
	}
	
	return false;
}

//return true to destroy the event sensor
bool runBuddyEvent(int eventSensorId)
{
	switch (eventSensorId)
	{
		case 15: narrate(1, 1, "Right, let's get going.", 4); return true;
		case 14: narrate(1, 1, "Ahh... clean fresh air. I sure need some after that LD48.", 4); scheduleEvent(19,1.5); return true;		
		case 20: narrate(1, 1, "Been here before?", 4); scheduleEvent(21,1.5); return true;		
		case 28: narrate(1, 1, "You crossed the swing bridge. So brave!", 4); scheduleEvent(29,1.5); return true;
		case 33: narrate(1, 1, "There's the lodge.", 4); return true;
	}
	
	return false;
}

//return true to destroy the event sensor
bool runCarEvent(int eventSensorId)
{
	switch (eventSensorId)
	{
		//narrate(int actorId, int msgType, const string &s, float timeoutSeconds)
		case 1: narrate(-1, 0, "Cars are for roads, not hiking trails...", 5); return true;
		case 2:	narrate(-1, 0, "Seriously now, the car is not really part of the game...", 5); return true;
		case 3:	narrate(-1, 0, "... and you can't push it past here anyway :)", 5); return true;
	}
	
	return false;
}

//there is no event sensor, only an id for these
void runScheduledEvent(int eventId)
{
	switch (eventId)
	{
		case 5: destroyJoint("weaklink2"); 
			scheduleEvent(6, 1.5);
			break;
		case 6: destroyJoint("weaklink3"); 
			break;
		case 7: narrate(0, 1, "Holy shit...!!", 3); 
			break;
		case 8: narrate(0, 1, "Uh oh... that was a long fall.", 6);
			scheduleEvent(9, 3);
			break;
		case 9: narrate(0, 1, "Doesn't look like anyone has ever come down here...", 6);
			scheduleEvent(10 , 3);
			break;
		case 10: narrate(0, 1, "I think I am...", 6);
			scheduleEvent(11 , 2);
			break;
		case 11: narrate(0, 1, "            ...alone.", 10);
			break;
		case 17: narrate(0, 1, "Whee! It's bouncy!", 6);
			scheduleEvent(18,1.5);
			break;
		case 18: narrate(1, 1, "See, this is why we can't have nice things.", 6); 
			break;
			
		case 19: narrate(0, 1, "Yup.", 4);
			scheduleEvent(26,1.5);
			break;
		case 26: narrate(1, 1, "That 2D physics game could be a winner.", 4);
			scheduleEvent(27,1.5);
			break;
		case 27: narrate(0, 1, "Yeah, Box2D kicks ass.", 4);
			break;
			
		case 21: narrate(0, 1, "No, this is the first time I've... dared.", 4);
			scheduleEvent(22,1.5);
			break;
		case 22: narrate(1, 1, "Aha, so you've heard the stories.", 4);
			scheduleEvent(23,1.5);
			break;
		case 23: narrate(0, 1, "That the ground is cursed? That's stupid.", 4);
			scheduleEvent(24,1.5);
			break;
		case 24: narrate(1, 1, "Don't worry, I'll protect you.", 4);
			scheduleEvent(25,1.5);
			break;
		case 25: narrate(0, 1, "Shutup. They're just silly stories.", 4);
			//scheduleEvent(25,1.5);
			break;
			
		case 29: narrate(0, 1, "Very funny.", 4);
			scheduleEvent(30,1.5);
			break;
		case 30: narrate(1, 1, "Don't worry, they're perfectly safe.", 4);
			//scheduleEvent(31,1.5);
			break;
			
		case 32: narrate(1, 1, "Not too far.", 4);
			break;
			
		case 35: narrate(0, 1, "Oh no... that can't be good.", 5);
			scheduleEvent(36,4);
			break;
		case 36: narrate(0, 1, "I just hope there's another exit.", 5);
			scheduleEvent(37,4);
			break;
		case 37: narrate(0, 1, "I don't like being alone...", 5);
			scheduleEvent(38,4);
			break;
		case 38: narrate(0, 1, "...alone sucks.", 5);
			break;			
			
		case 44: narrate(0, 1, "Well that's it. I'm stuck down here.", 5);
			scheduleEvent(45,4);
			break;
		case 45: narrate(0, 1, "...alone.", 5);
			scheduleEvent(46,4);
			break;
		case 46: narrate(-1, 0, "You sure about that?", 15);
			scheduleEvent(47,4);
			break;
		case 47: narrate(0, 1, "Totally alone... or am I?", 20);
			break;
			
		case 49: narrate(0, 1, "Kittens! Now I'm not alone, yay!", 5);
			scheduleEvent(50,4);
			break;
		case 50: narrate(0, 1, "And I won't be hungry for a while either.", 5);
			scheduleEvent(51,4);
			break;
		case 51: narrate(0, 1, "...just kidding ;)", 5);
			scheduleEvent(52,5);
			break;
                case 52: narrate(-1, 0, "Congratulations, you have completed the game.\n\nThis game was made within a 48 hour period for the 22nd\n Ludum Dare competition, Dec 2011. The theme was 'Alone'.\n\nMany thanks to Erin Catto, Laurent Gomila, Andreas Jonsson\n and all contributors to Box2D, SFML and Angelscript.\n\nSee www.iforce2d.net for Box2D tutorials and\n the editor used to create this level.\n\nPress R to reset the game.", 600);
			break;
	}
}








